Use the platform specific ELF branding expected under FreeBSD.
This is similar to what the vendor ld(1) does on this platform.

Index: bfd/elf.c
--- bfd/elf.c.orig	2005-03-06 03:02:15 +0100
+++ bfd/elf.c	2005-05-03 19:48:25 +0200
@@ -4621,6 +4621,12 @@
   else
     i_ehdrp->e_type = ET_REL;
 
+  /* OpenPKG platform branding BEGIN */
+#if defined(OPENPKG_OS_FREEBSD)
+  i_ehdrp->e_ident[EI_OSABI] = ELFOSABI_FREEBSD;
+#endif
+  /* OpenPKG platform branding END */
+
   switch (bfd_get_arch (abfd))
     {
     case bfd_arch_unknown:

-----------------------------------------------------------------------------

Support FreeBSD >= 4.10 by fixing platform detection.

Index: bfd/configure
--- bfd/configure.orig	2005-05-02 21:43:54 +0200
+++ bfd/configure	2005-05-03 19:49:53 +0200
@@ -9956,6 +9956,10 @@
   i[3-7]86-*-bsdi)
 	COREFILE=
 	;;
+  i[3456]86-*-freebsd4.1[0-9]*)
+	COREFILE=''
+	TRAD_HEADER='"hosts/i386bsd.h"'
+	;;
   i[3-7]86-*-bsd* | i[3-7]86-*-freebsd[123] | i[3-7]86-*-freebsd[123]\.* | i[3-7]86-*-freebsd4\.[01234] | i[3-7]86-*-freebsd4\.[01234]\.* | i[3-7]86-*-freebsd*aout*)
 	COREFILE=trad-core.lo
 	TRAD_HEADER='"hosts/i386bsd.h"'

-----------------------------------------------------------------------------

Fight problems with --disable-nls under Solaris

Index: binutils/bucomm.h
--- binutils/bucomm.h.orig	2005-08-16 21:35:21.000000000 +0200
+++ binutils/bucomm.h	2005-09-13 16:55:29.276456000 +0200
@@ -125,6 +125,11 @@
 # endif /* HAVE_ALLOCA_H */
 #endif
 
+#ifndef ENABLE_NLS
+# define _LIBINTL_H
+# define _LIBGETTEXT_H
+#endif
+
 #ifdef HAVE_LOCALE_H
 # include <locale.h>
 #endif
Index: gas/asintl.h
--- gas/asintl.h.orig	2005-05-05 11:12:43.000000000 +0200
+++ gas/asintl.h	2005-09-13 16:58:29.082469000 +0200
@@ -20,6 +20,11 @@
    Software Foundation, 51 Franklin Street - Fifth Floor, Boston, MA
    02110-1301, USA.  */
 
+#ifndef ENABLE_NLS
+# define _LIBINTL_H
+# define _LIBGETTEXT_H
+#endif
+
 #ifdef HAVE_LOCALE_H
 # include <locale.h>
 #endif
Index: gprof/gprof.c
--- gprof/gprof.c.orig	2005-04-23 19:13:31.000000000 +0200
+++ gprof/gprof.c	2005-09-13 17:13:52.242443000 +0200
@@ -189,8 +189,10 @@
 #if defined (HAVE_SETLOCALE)
   setlocale (LC_CTYPE, "");
 #endif
+#ifdef ENABLE_NLS
   bindtextdomain (PACKAGE, LOCALEDIR);
   textdomain (PACKAGE);
+#endif
 
   whoami = argv[0];
   xmalloc_set_program_name (whoami);
Index: ld/ld.h
--- ld/ld.h.orig	2005-06-09 04:05:46.000000000 +0200
+++ ld/ld.h	2005-09-13 17:24:03.767249000 +0200
@@ -23,6 +23,11 @@
 #ifndef LD_H
 #define LD_H
 
+#ifndef ENABLE_NLS
+# define _LIBINTL_H
+# define _LIBGETTEXT_H
+#endif
+
 #ifdef HAVE_LOCALE_H
 # include <locale.h>
 #endif
Index: ld/Makefile.in
--- ld/Makefile.in.orig	2005-01-23 06:36:37 +0100
+++ ld/Makefile.in	2005-09-21 21:06:55 +0200
@@ -139,7 +139,7 @@
 # We put the scripts in the directory $(scriptdir)/ldscripts.
 # We can't put the scripts in $(datadir) because the SEARCH_DIR
 # directives need to be different for native and cross linkers.
-scriptdir = $(tooldir)/lib
+scriptdir = $(libdir)
 
 EMUL = @EMUL@
 EMULATION_OFILES = @EMULATION_OFILES@
